==> haskell-email-validate-2.3.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.1
id: email-validate-2.3.1-3cUPInZZ0fxJCQHuwrECGy
key: email-validate-2.3.1-3cUPInZZ0fxJCQHuwrECGy
license: BSD3
maintainer: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
author: George Pollard <porges@porg.es>
exposed: True
indefinite: False
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
abi: 5b9f28e56b5511f0cbf5d00210842cdf
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/email-validate-2.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/email-validate-2.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/email-validate-2.3.1
hs-libraries: HSemail-validate-2.3.1-3cUPInZZ0fxJCQHuwrECGy
depends:
    base-4.10.0.0 attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j
    bytestring-0.10.8.2 template-haskell-2.12.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=408c5a9ef40ae69c083ed9d4aba83592
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: email-validate
version: 2.3.1
id: email-validate-2.3.1-EjdxoskbP1QJJVrkGicaGY
key: email-validate-2.3.1-EjdxoskbP1QJJVrkGicaGY
license: BSD3
maintainer: George Pollard <porges@porg.es>
stability: experimental
homepage: https://github.com/Porges/email-validate-hs
synopsis: Email address validation
description:
    Validating an email address string against RFC 5322
category: Text
author: George Pollard <porges@porg.es>
exposed: True
indefinite: False
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate
abi: 5de3456335b8d4a2ae129ff7514c9527
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/email-validate-2.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/email-validate-2.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/email-validate-2.3.1
hs-libraries: HSemail-validate-2.3.1-EjdxoskbP1QJJVrkGicaGY
depends:
    base-4.10.0.0 attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    bytestring-0.10.8.2 template-haskell-2.12.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
haddock-interfaces: /usr/share/doc/haskell-email-validate/html/email-validate.haddock
haddock-html: /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
